/**
 * Copyright 1998-2007, CHISEL Group, University of Victoria, Victoria, BC, Canada.
 * All rights reserved.
 */

package ca.uvic.csr.shrimp.gui;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.beans.PropertyVetoException;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JDesktopPane;
import javax.swing.JLabel;

/**
 * This pane handles the layouts of the internal windows for the
 * shrimp frame.
 */
public class ScrollDesktopPane extends JDesktopPane {

    private DeskLayoutManager deskLayoutManager = null;
	
	private Icon brandingIcon;
	private JLabel imageLabel;
	private int imageWidth;
	private int imageHeight;
	
    /**
     * Constructor
     */   
    public ScrollDesktopPane(Image brandingImage, Icon brandingIcon) {
		deskLayoutManager = new DeskLayoutManager(this);
		this.brandingIcon = brandingIcon;
		
		// Get the icon image
		Icon icon = new ImageIcon(brandingImage);
		imageLabel = new JLabel(icon);
		
		imageWidth = icon.getIconWidth();
		imageHeight = icon.getIconHeight();
		imageLabel.setSize(imageWidth,imageHeight);
		
		this.add(imageLabel, -10); // -1 sends it behind the DEFAULT_LAYER
	}
    
    

	public DesktopInternalFrame addFrame (String title) {
		DesktopInternalFrame frame = new DesktopInternalFrame(this, title, brandingIcon);

		int parentWidth = this.getWidth();
		int parentHeight = this.getHeight();
		int width = (int)(parentWidth * 0.85);
		int height = (int)(parentHeight * 0.85);
		
		int xpos;
		int ypos;
		
		if(getSelectedFrame() != null) {
			try {
				getSelectedFrame().setMaximum(false);
			} catch (PropertyVetoException e) {
				e.printStackTrace();
			}
			
			xpos = getSelectedFrame().getX() + 20;
			ypos = getSelectedFrame().getY() + 20;
			
			if(xpos > (parentWidth-40) || ypos > (parentHeight-40)) {
				xpos = (parentWidth - width) / 2;
				ypos = (parentHeight - height) / 2;
			}
		}
		else {
			xpos = (parentWidth - width) / 2;
			ypos = (parentHeight - height) / 2;
		}
		
		frame.setBounds(xpos, ypos, width, height);
		
		this.add(frame, DEFAULT_LAYER);
		
		return frame;
	}
	
    /**
     * Gets the DeskLayoutManager of this ScrollDesktopPane.
     */
    public DeskLayoutManager getDeskLayoutManager() {
 		if(deskLayoutManager == null) {
		    deskLayoutManager = new DeskLayoutManager(this);
		}
		return deskLayoutManager;
    }

    public void maximizeFirstFrame() {
    	deskLayoutManager.maximizeFirstFrame();
    }
    
    /**
     * Tiles all the internal frames of this ScrollDesktopPane.
     */
    public void tileAllFrames() {
		deskLayoutManager.tile();
    }

    /**
     * Cascades all the internal frames of this ScrollDesktopPane.
     */
    public void cascadeAllFrames() {
		deskLayoutManager.cascade();
    }

    /**
     * Standardizes all the internal frames of this ScrollDesktopPane
     * to the specified size.
     */
    public void standardizeAllFrames(Dimension size) {
		deskLayoutManager.standardizeAll(size);
    }

    /**
     * Closes all the internal frames of this ScrollDesktopPane.
     */
    public void closeAllFrames() {
		deskLayoutManager.closeAll();
    }

    /**
     * Deiconizes all the internal frames of this ScrollDesktopPane.
     */
    public void deiconizeAllFrames() {
		deskLayoutManager.deiconizeAll();
    }

    /**
     * Iconizes all the internal frames of this ScrollDesktopPane.
     */
    public void iconizeAllFrames() {
		deskLayoutManager.iconizeAll();
    }

	/**
	 * @see javax.swing.JComponent#paintComponent(Graphics)
	 */
	protected void paintComponent(Graphics g) {
		super.paintComponent(g);		
    	imageLabel.setLocation((this.getWidth() - imageWidth)/2, (this.getHeight() - imageHeight)/2);
	}
	
}




